@@ -57,6 +57,8 @@
 
 extern int xls_debug;
 
+// static void xls_showBOUNDSHEET(void* bsheet);
+
 static const DWORD colors[] =
     {
         0x000000,
@@ -167,16 +169,18 @@ static int asprintf(char **ret, const char *format, ...)
 static int asprintf(char **ret, const char *format, ...)
 {
 	int i;
-    char *str;
+	char *str;
 
 	va_list ap;
 
 	va_start(ap, format); 
-
 	i = vsnprintf(NULL, 0, format, ap) + 1;
-	str = (char *)malloc(i);
-	i = vsnprintf(str, i, format, ap);
+	va_end(ap);
 
+	str = (char *)malloc(i);
+
+	va_start(ap, format);
+	i = vsnprintf(str, i, format, ap);
 	va_end(ap);
 
 	*ret = str;
@@ -624,7 +628,7 @@ void xls_showXF(XF8* xf)
     printf("GroundColor: 0x%x\n",xf->groundcolor);
 }
 
-BYTE *xls_getfcell(xlsWorkBook* pWB,struct st_cell_data* cell,WORD *label)
+BYTE *xls_getfcell(xlsWorkBook* pWB,struct st_cell_data* cell,BYTE *label)
 {
     struct st_xf_data *xf;
 	WORD	len;
@@ -635,16 +639,16 @@ BYTE *xls_getfcell(xlsWorkBook* pWB,struct st_cell_data* cell,WORD *label)
     switch (cell->id)
     {
     case XLS_RECORD_LABELSST:
-		//printf("WORD: %u short: %u str: %s\n", *label, xlsShortVal(*label), pWB->sst.string[xlsShortVal(*label)].str );
-        asprintf(&ret,"%s",pWB->sst.string[xlsShortVal(*label)].str);
+		//printf("WORD: %u short: %u str: %s\n", *(DWORD_UA *)label, xlsIntVal(*(DWORD_UA *)label), pWB->sst.string[xlsIntVal(*(DWORD_UA *)label)].str );
+        asprintf(&ret,"%s",pWB->sst.string[xlsIntVal(*(DWORD_UA *)label)].str);
         break;
     case XLS_RECORD_BLANK:
     case XLS_RECORD_MULBLANK:
-        asprintf(&ret, "");
+        asprintf(&ret, "%s", "");
         break;
     case XLS_RECORD_LABEL:
 		len = xlsShortVal(*label);
-        label++;
+        label += 2;
 		if(pWB->is5ver) {
 			asprintf(&ret,"%.*s", len, (char *)label);
 			//printf("Found BIFF5 string of len=%d \"%s\"\n", len, ret);
